@@ -13,45 +13,46 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from abc import ABCMeta, abstractmethod
+from abc import abstractmethod
 from collections.abc import Callable, Iterator, MutableMapping
 from functools import partial
 from inspect import Signature, isfunction
-from typing import Any, Final, TypeVar
+from typing import Any, Final, TypeAlias, TypeVar
 
 from ._errors import Error, ErrorEnum
 
 __all__: Final[list[str]] = ["Dispatcher"]
 
-_F = TypeVar("_F", bound=Callable)
+_AnyCallable: TypeAlias = Callable[..., Any]
+_F = TypeVar("_F", bound=_AnyCallable)
 
 
-class BaseDispatcher(MutableMapping[str, _F], metaclass=ABCMeta):
-    __slots__: list[str] = ["_references"]
+class BaseDispatcher(MutableMapping[str, _AnyCallable]):
+    __slots__: list[str] = ["_registry"]
 
-    def __init__(self, /, **kwargs: _F) -> None:
-        self._references: Final[dict[str, _F]] = kwargs.copy()
+    def __init__(self) -> None:
+        self._registry: Final[dict[str, _AnyCallable]] = dict()
 
     def __hash__(self) -> int:
         return hash(frozenset(self.items()))
 
-    def __getitem__(self, key: str, /) -> _F:
-        return self._references[key]
+    def __getitem__(self, key: str, /) -> _AnyCallable:
+        return self._registry[key]
 
-    def __setitem__(self, key: str, value: _F, /) -> None:
-        self._references[key] = value
+    def __setitem__(self, key: str, value: _AnyCallable, /) -> None:
+        self._registry[key] = value
 
     def __delitem__(self, key: str, /) -> None:
-        del self._references[key]
+        del self._registry[key]
 
     def __len__(self) -> int:
-        return len(self._references)
+        return len(self._registry)
 
     def __iter__(self) -> Iterator[str]:
-        return iter(self._references)
+        return iter(self._registry)
 
     def __contains__(self, obj: Any, /) -> bool:
-        return obj in self._references
+        return obj in self._registry
 
     @abstractmethod
     def register(self, user_function: _F | None = None, *, function_name: str | None = None) -> _F | Callable[[_F], _F]:
@@ -62,22 +63,14 @@ class BaseDispatcher(MutableMapping[str, _F], metaclass=ABCMeta):
         raise NotImplementedError
 
 
-class Dispatcher(BaseDispatcher[Callable]):
+class Dispatcher(BaseDispatcher):
     """
     The :py:class:`collections.abc.MutableMapping` subclass representing the storage of user-defined functions.
-    Besides the methods inherited from the parent class,
-    this class provides methods for the registering and dispatching user-defined functions.
-
-    .. note::
-        Unlike the parent class :py:class:`collections.abc.MutableMapping`,
-        this object is provided the hash value by invoking :py:func:`hash` method.
-        So any instance of the :class:`jsonrpc.Dispatcher` class is hashable
-        and it can be stored in the :py:class:`frozenset` for example.
     """
     __slots__: tuple[str, ...] = ()
 
     def __repr__(self) -> str:
-        return f"<{__package__}.{self.__class__.__name__}()>"
+        return f"<{self.__class__.__name__}()>"
 
     def register(self, user_function: _F | None = None, *, function_name: str | None = None) -> _F | Callable[[_F], _F]:
         """
@@ -138,7 +131,7 @@ class Dispatcher(BaseDispatcher[Callable]):
         :returns: Result of execution the user-defined function.
         """
         try:
-            user_function: Final[Callable] = self[function_name]
+            user_function: _AnyCallable = self[function_name]
         except KeyError as exc:
             raise Error(code=ErrorEnum.METHOD_NOT_FOUND, message=f"Function {function_name!r} isn't found") from exc
 
@@ -147,8 +140,10 @@ class Dispatcher(BaseDispatcher[Callable]):
         except TypeError as exc:
             raise Error(code=ErrorEnum.INVALID_PARAMETERS, message=f"Invalid parameters: {exc!s}") from exc
 
+        # Save the callback for future use:
+        callback: Final[partial] = partial(user_function, *args, **kwargs)
+
         try:
-            callback: Final[partial] = partial(user_function, *args, **kwargs)
             return callback()
         except Error:
             raise
