@@ -76,10 +76,10 @@ class Error(BaseError):
         self._data: Final[Any] = data
 
     def __str__(self) -> str:
-        return f"{self._message!s}\x20\x28{self._code:d}\x29"
+        return f"{self._message!s}\u0020\u0028{self._code:d}\u0029"
 
     def __repr__(self) -> str:
-        return f"<{__package__}.{self.__class__.__name__}(" \
+        return f"<{self.__class__.__name__}(" \
             f"code={self._code!r}, " \
             f"message={self._message!r}, " \
             f"data={self._data!r})>"
