@@ -14,14 +14,17 @@
 # limitations under the License.
 
 from abc import ABCMeta, abstractmethod
-from json.decoder import JSONDecoder
-from json.encoder import JSONEncoder
+from functools import cached_property
+from json import JSONDecoder, JSONEncoder
 from typing import Any, Final
 
 from ._errors import Error, ErrorEnum
 
 __all__: Final[list[str]] = ["JSONSerializer"]
 
+# Eliminate a whitespaces to get the most compact JSON representation:
+_JSON_COMPACT_SEPARATORS: Final[tuple[str, str]] = "\u002c", "\u003a"
+
 # Ensure to output JSON as a strict JavaScript subset:
 _JSON_ESCAPE_TABLE: Final[dict[int, str]] = {
     0x2028: "\\u2028",
@@ -45,16 +48,17 @@ class JSONSerializer(BaseSerializer):
     """
     Simple class for JSON serialization and deserialization.
     Combines the :py:class:`json.JSONEncoder` and :py:class:`json.JSONDecoder` objects.
-    Primarily used by the :class:`jsonrpc.WSGIHandler` instance for (de)serialization the requests and responses.
     """
-    __slots__: list[str] = ["_encoder", "_decoder"]
-
-    def __init__(self) -> None:
-        self._encoder: Final[JSONEncoder] = JSONEncoder(ensure_ascii=False, separators=("\x2C", "\x3A"))
-        self._decoder: Final[JSONDecoder] = JSONDecoder(strict=False)
-
     def __repr__(self) -> str:
-        return f"<{__package__}.{self.__class__.__name__}()>"
+        return f"<{self.__class__.__name__}()>"
+
+    @cached_property
+    def _encoder(self) -> JSONEncoder:
+        return JSONEncoder(ensure_ascii=False, separators=_JSON_COMPACT_SEPARATORS)
+
+    @cached_property
+    def _decoder(self) -> JSONDecoder:
+        return JSONDecoder()
 
     def serialize(self, obj: Any, /) -> bytes:
         """
