@@ -17,13 +17,13 @@ from collections.abc import Iterable, Iterator, MutableMapping, MutableSequence
 from types import TracebackType
 from typing import Any, Final, Protocol, TypeAlias
 
-__all__: Final[tuple[str, ...]] = (
+__all__: Final[list[str]] = [
     "ExcInfo",
     "Headers",
     "InputStream",
     "StartResponse",
     "WSGIEnvironment"
-)
+]
 
 Headers: TypeAlias = MutableSequence[tuple[str, str]]
 ExcInfo: TypeAlias = tuple[type[Exception], Exception, TracebackType | None]
