@@ -13,17 +13,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from collections.abc import Hashable, Iterable, MutableMapping
+from collections.abc import Callable, Hashable, Iterable, Iterator, MutableMapping
+from itertools import filterfalse, tee
 from time import gmtime
-from typing import Any, Final, Literal
+from typing import Any, Final, Literal, TypeVar
 
 __all__: Final[list[str]] = [
+    "boolean_sorter",
     "http_rfc2822_datetime",
     "make_hashable",
     "Undefined",
     "UndefinedType"
 ]
 
+_T = TypeVar("_T")
+
+
+def boolean_sorter(iterable: Iterable[_T], predicate: Callable[[_T], bool] | None = None, /) -> Iterator[_T]:
+    left, right = tee(iterable)
+    yield from filter(predicate, left)
+    yield from filterfalse(predicate, right)
+
 
 def http_rfc2822_datetime(timestamp: float | None = None) -> str:
     tm_year, tm_mon, tm_mday, tm_hour, tm_min, tm_sec, tm_wday, _, _ = gmtime(timestamp)
