@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from abc import ABCMeta, abstractmethod
+from abc import abstractmethod
 from binascii import b2a_base64 as b64encode
 from collections.abc import Callable, Iterator, MutableMapping, MutableSequence
 from functools import partial
@@ -38,7 +38,7 @@ _AnyRequest: TypeAlias = Request | Error | BatchRequest
 _AnyResponse: TypeAlias = Response | BatchResponse | None
 
 
-class BaseWSGIHandler(MutableMapping[str, Any], metaclass=ABCMeta):
+class BaseWSGIHandler(MutableMapping[str, Any]):
     __slots__: list[str] = ["_options"]
 
     def __init__(self, /, **kwargs: Any) -> None:
@@ -190,7 +190,7 @@ class WSGIHandler(BaseWSGIHandler):
     serializer: ClassVar[JSONSerializer] = JSONSerializer()
 
     def __repr__(self) -> str:
-        return f"<{__package__}.{self.__class__.__name__}()>"
+        return f"<{self.__class__.__name__}()>"
 
     @classmethod
     def handle_request(cls, obj: _AnyRequest, /) -> _AnyResponse:
